import React from 'react';
import { T, F } from 'ramda';
import { InputValidation } from './input-validation';

describe('<InputValidation />', () => {
  let wrapper;

  beforeAll(() => {
    wrapper = shallow(<InputValidation addValid={false} isValidCb={jest.fn()} errorMessage="test.error.msg" type="text" />);
  });

  describe('when input currently should not be validated', () => {
    test('should match snapshot', () => {
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('when input should be validated', () => {
    describe('and its valid', () => {
      beforeAll(() => {
        wrapper.setProps({
          addValid: true,
          isValidCb: jest.fn(T),
        });
      });

      test('should match snapshot', () => {
        expect(wrapper).toMatchSnapshot();
      });
    });

    describe('and its not valid', () => {
      beforeAll(() => {
        wrapper.setProps({
          addValid: true,
          isValidCb: jest.fn(F),
        });
      });

      test('should match snapshot', () => {
        expect(wrapper).toMatchSnapshot();
      });
    });
  });

  describe('when isValidCb not defined', () => {
    test('should always return false', () => {
      const wrapper2 = shallow(<InputValidation addValid errorMessage="test.error.msg" type="text" />);
      expect(wrapper2).toMatchSnapshot();
    });
  });
});
