import { storiesOf } from '@storybook/react';
import { withKnobs, boolean } from '@storybook/addon-knobs';

import React, { Component } from 'react';
import { IntlProvider } from 'react-intl';
import { Button } from 'reactstrap';

import { BalanceItemWithHint, SCR, SP } from './balance-item-with-hint';
import { IconScr } from '../../icons/icon-scr/icon-scr';
import { IconScrPulse } from '../../icons/icon-scr-pulse/icon-scr-pulse';

const SCR_HINT = 'SCR_HINT';

const MAPPING_POPOVER_ITEMS = {
  SCR: [true, false, false],
  SP: [false, true, false],
  VP: [false, false, true],
  allItemsFalse: [false, false, false],
};

class HeaderBalance extends Component {
  state = {
    popoverOpenSCR: false,
    popoverOpenSP: false,
    popoverOpenVP: false,
  };

  startCoach = () => this.setState({ popoverOpenSCR: true });

  closeAllCoachMarks = () => {
    this.setState({
      popoverOpenSCR: false,
      popoverOpenSP: false,
      popoverOpenVP: false,
    });
  };

  toggleCoachMarkPopover = (e) => {
    const { value } = e.currentTarget;
    const [popoverOpenSCR, popoverOpenSP, popoverOpenVP] = MAPPING_POPOVER_ITEMS[value];

    this.setState({
      popoverOpenSCR,
      popoverOpenSP,
      popoverOpenVP,
    });
  };

  render() {
    const { popoverOpenSCR, popoverOpenSP, popoverOpenVP } = this.state;

    return (
      <div className="ml-8">
        <IntlProvider locale="en">
          <BalanceItemWithHint
            startCoach={this.startCoach}
            value={123555}
            type={SCR}
            icon={<IconScr />}
            target={SCR_HINT}
            helpTitleId="blog.header.coach-mark.SCR-title"
            helpDescId="blog.header.coach-mark.SCR-description"
            iconHelp={<IconScrPulse />}
            disabledCoachMarks={boolean('disabledCoachMarks', true)}
            isOpenCoachmark={boolean('isOpenCoachmark', false)}
            toggleCoachMarkPopover={this.toggleCoachMarkPopover}
            closeAllCoachMarks={this.closeAllCoachMarks}
            popoverOpenSCR={popoverOpenSCR}
            popoverOpenSP={popoverOpenSP}
            popoverOpenVP={popoverOpenVP}
            coachMarkBtnValue={SP}
            coachMarkBtnIntlId="blog.header.coach-mark.button.next"
          >
            <div className="h5 pt-0_5">SCR 10000</div>
            <div className="text-gray-light-secondary">$ 10000</div>
            <Button size="xs" color="blue-b30" block className="mt-2_5 mb-0_5" onClick={this.onClickBuySCR}>
              Buy SCR
            </Button>
          </BalanceItemWithHint>
        </IntlProvider>
      </div>
    );
  }
}

storiesOf('Header', module)
  .addDecorator(withKnobs)
  .add('BalanceItemWithHint dark', () => <HeaderBalance />);
