import React from 'react';

import { BalanceItemWithHint, SCR } from './balance-item-with-hint';

import { diveFormattedMessages } from '../../../test/unit/helpers/dive-formatted-messages';

jest.mock('react-intl');

jest.spyOn(React, 'createRef');
React.createRef.mockImplementation(() => ({
  current: {
    click: jest.fn(),
  },
}));

describe('<BalanceItemWithHint />', () => {
  let wrapper;
  const props = {
    value: '100',
    titl: 'Current SCR Balance',
    target: 'scr-balance',
    helpTitleId: 'blog.header.coach-mark.SCR-title',
    helpDescId: 'blog.header.coach-mark.SCR-description',
    type: 'type',
    icon: <span>some icon</span>,
    iconHelp: <span>some icon</span>,
    disabledCoachMarks: false,
    isOpenCoachmark: false,
    toggleCoachMarkPopover: jest.fn(),
    popoverOpenSCR: false,
    popoverOpenSP: false,
    popoverOpenVP: false,
    coachMarkBtnValue: 'coachMarkBtnValue',
    coachMarkBtnIntlId: 'coachMarkBtnIntlId',
  };

  test('should match snapshot', () => {
    wrapper = shallow(<BalanceItemWithHint {...props}><span>children</span></BalanceItemWithHint>);
    diveFormattedMessages(wrapper);
    expect(wrapper).toMatchSnapshot();
  });

  describe('when user click to item', () => {
    test('should change state to show popover', () => {
      wrapper.instance().togglePopover();
      expect(wrapper.instance().state.popoverOpen).toBe(true);
    });
  });

  describe('when user click to help icon', () => {
    test('should change state to show popover', () => {
      wrapper.instance().toggleHelpPopover();
      expect(wrapper.instance().state.popoverHelperOpen).toBe(true);
    });
  });

  describe('when render dots navigation', () => {
    beforeAll(() => {
      wrapper.setProps({
        popoverOpenSCR: false,
        popoverOpenSP: false,
        popoverOpenVP: false,
      });
    });

    afterEach(() => {
      wrapper.setProps({
        popoverOpenSCR: false,
        popoverOpenSP: false,
        popoverOpenVP: false,
      });
    });

    test('should render with primary color only SCR step', () => {
      wrapper.setProps({
        popoverOpenSCR: true,
      });

      expect(wrapper).toMatchSnapshot();
    });

    test('should render with primary color only SP step', () => {
      wrapper.setProps({
        popoverOpenSP: true,
      });

      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('when user hovers item', () => {
    test('balance item click event should be triggered', () => {
      const wrapper2 = shallow(<BalanceItemWithHint {...props}><span>children</span></BalanceItemWithHint>);
      wrapper2.instance().handleBalanceItemHover({ preventDefault: jest.fn() });
      expect(wrapper2.instance().balanceItemRef.current.click).toHaveBeenCalled();
    });

    test('balance item click event should be not triggered when popover open', () => {
      const wrapper2 = shallow(<BalanceItemWithHint {...props}><span>children</span></BalanceItemWithHint>);

      wrapper2.setState({
        popoverOpen: true,
      });

      wrapper2.instance().handleBalanceItemHover({ preventDefault: jest.fn() });

      expect(wrapper2.instance().balanceItemRef.current.click).not.toHaveBeenCalled();
    });
  });

  test('should show coache when user come first time', () => {
    const startCoach = jest.fn();

    wrapper.setProps({
      startCoach,
      type: SCR,
    });

    wrapper.instance().componentDidMount();

    expect(startCoach).toHaveBeenCalledTimes(1);
  });
});
