import React from 'react';
import { LangSwitcher } from './lang-switcher';
import { changeLocation } from '../../helpers/change-location';

jest.mock('../../helpers/change-location');
process.env.DOMAIN = 'com';

describe('<LangSwitcher />', () => {
  const wrapper = shallow(<LangSwitcher locale="en-us" />);

  test('when no locales from props should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  test('should toggle dropdown', () => {
    wrapper.instance().toggle();
    expect(wrapper.instance().state.dropdownOpen).toBe(true);
  });

  test('should not change location when locale equals new locale', () => {
    const event = {
      target: {
        value: 'en-us',
      },
    };
    wrapper.instance().changeLocale(event);
    expect(changeLocation).not.toHaveBeenCalled();
  });

  test('should change location when locale not equal new locale', () => {
    const event = {
      target: {
        value: 'ru-ru',
      },
    };
    wrapper.instance().changeLocale(event);

    expect(changeLocation).toHaveBeenCalled();
  });

  describe('when locales is Array', () => {
    test('should', () => {
      expect(shallow(<LangSwitcher locale="en-us" locales={['en-us', 'ru-ru', 'es-es']} />)).toMatchSnapshot();
    });
  });

  describe('when locales is Object', () => {
    const event = {
      target: {
        value: 'ru-ru',
      },
    };

    test('should', () => {
      const wrapper2 = shallow(<LangSwitcher locale="en-us" locales={{ 'en-us': 'com', 'ru-ru': 'net', 'es-es': 'es' }} />);
      wrapper2.instance().changeLocale(event);
      expect(wrapper2).toMatchSnapshot();
    });

    test('should', () => {
      const wrapper2 = shallow(<LangSwitcher locale="en-us" locales={{ 'en-us': 'com', 'ru-ru': 'net', 'es-es': 'es' }} />);
      wrapper2.instance().changeLocale({
        target: {
          value: 'loh-nah',
        },
      });
      expect(wrapper2).toMatchSnapshot();
    });

    describe('when `isWithinHeader` prop is TRUE', () => {
      describe('and `isWhite` is FALSE (default one)', () => {
        test('should match snapshot', () => {
          const wrapper3 = shallow(<LangSwitcher
            locale="en-us"
            locales={{ 'en-us': 'com', 'ru-ru': 'net', 'es-es': 'es' }}
            isWithinHeader
          />);
          expect(wrapper3).toMatchSnapshot();
        });
      });

      describe('and `isWhite` is TRUE', () => {
        test('should match snapshot', () => {
          const wrapper3 = shallow(<LangSwitcher
            locale="en-us"
            locales={{ 'en-us': 'com', 'ru-ru': 'net', 'es-es': 'es' }}
            isWithinHeader
            isWhite
          />);
          expect(wrapper3).toMatchSnapshot();
        });
      });
    });
  });
});
